@@ -1,5 +1,5 @@
 module EngineProject
-  class Engine < Rails::Engine
+  class Engine < ::Rails::Engine
     isolate_namespace EngineProject
   end
 end
