@@ -10,8 +10,18 @@ ScssProject::Application.configure do
   config.eager_load = false
 
   # Configure static asset server for tests with Cache-Control for performance
-  config.serve_static_assets = true
-  config.static_cache_control = "public, max-age=3600"
+  if config.respond_to?(:public_file_server)
+    config.public_file_server.enabled = true
+  elsif config.respond_to?(:serve_static_files)
+    config.serve_static_files = true
+  else
+    config.serve_static_assets = true
+  end
+  if config.respond_to?(:public_file_server)
+    config.public_file_server.headers = { 'Cache-Control' => 'public, max-age=3600' }
+  else
+    config.static_cache_control = "public, max-age=3600"
+  end
 
   # Show full error reports and disable caching
   config.consider_all_requests_local       = true
